@@ -2,16 +2,22 @@ import pytest
 
 from rumydata import table, Layout, field
 from rumydata.rules import row as rr, header as hr
+from tests.utils import file_row_harness
 
 
 def test_row_good(basic):
-    assert not table.Layout(basic).check_row(['1', '2', '2020-01-01', 'X'])
+    row = ['1', '2', '2020-01-01', 'X']
+    assert not Layout(basic).check_row(row)
+    assert not file_row_harness(row, basic)
 
 
 def test_row_choice(basic):
-    lay = Layout({'c1': field.Choice(['x'], nullable=True)})
+    fields = {'c1': field.Choice(['x'], nullable=True)}
+    lay = Layout(fields)
     assert not lay.check_row(['x'])
     assert not lay.check_row([''])
+    assert not file_row_harness(['x'], fields)
+    assert not file_row_harness([''], fields)
 
 
 @pytest.mark.parametrize('value,err', [
@@ -20,12 +26,13 @@ def test_row_choice(basic):
 ])
 def test_row_bad(basic, value, err):
     assert table.Layout(basic)._has_error(value, err.rule_exception(), rule_type=rr.Rule)
+    with pytest.raises(AssertionError):
+        file_row_harness(value, basic)
 
 
 def test_header_good(basic):
     assert not table.Layout(basic).check_header(['col1', 'col2', 'col3', 'col4'])
 
-
 @pytest.mark.parametrize('value,err', [
     (['col1', 'col2'], hr.NoMissing),
     (['col1', 'col2', 'col2'], hr.NoDuplicate),
